function [Uf,Vf] = apply_tanh_tapering(x,y,U,V, n)
% APPLY_TANH_TAPERING  Tapers U,V with the tanh method.
% Inputs: 
%       x: [n, 1] or [1, n] double, x-coordinates of velocity field
%       y: [m, 1] or [1, m] double, y-coordinates of velocity field
%       U: [m, n] double, u-component of velocity field
%       V: [m, n] double, v-component of velocity field
%       n: double, edge tapering effect, more narrow and dramatic if
%          n is greater
% Outputs:
%       Uf: tapered u-component of velocity field
%       Vf: tapered v-component of velocity field

[X,Y] = meshgrid(x,y);

%{
T = sin( (X-x(1).*ones(size(X))) .* (pi./ (x(end)-x(1))) ) ...
    .* sin( (Y-y(1).*ones(size(Y))) .* (pi./ (y(end)-y(1))) );
%}

dX = min(x(end)-x(1), y(end)-y(1)) ./n; % adjust edge factor to domain size

left = tanh( (X-x(1))./dX); right = tanh((-X+x(end))./dX);
top = tanh( (Y-y(1))./dX); bottom = tanh((-Y+y(end))./dX);
T = (left + right - 1) .* (top + bottom - 1); % tapering mask

% Apply tapering mask to U, V
Uf = U .* T; Vf = V .* T;

return