function [k1, k2, uu] = calc_Corr_fourier(X,Y,U1,V1, U2, V2)
% CALC_CORR_FOURIER  Calculates the 2-dimensional spectral correlation
%                    between two velocity fields, (U1, V1) and (U2, V2).
% Inputs: 
%       X: [n, 1] or [1, n] double, x-coordinates of both velocity fields
%       Y: [m, 1] or [1, m] double, y-coordinates of both velocity fields
%       U1: [m, n] double, u-component of velocity field 1
%       V1: [m, n] double, v-component of velocity field 1
%       U2: [m, n] double, u-component of velocity field 2
%       V2: [m, n] double, v-component of velocity field 2
% Outputs:
%       k1: wavenumber in x-direction
%       k2: wavenumber in y-direction
%       uu: [m, n] complex, 2-dimensional spectral correlation between the
%           two input velocity fields; equals auto-correlation if U1 = U2,
%           V1 = V2.


[k1, k2] = get_k_2dFourier(X, Y);
dx = abs(X(2)-X(1)); dy = abs(Y(2)-Y(1));

u1 = fftshift(fft2(U1)).*dx; v1 = fftshift(fft2(V1)).*dy;
u2 = fftshift(fft2(U2)).*dx; v2 = fftshift(fft2(V2)).*dy;

uu = 0.5 .* ((u1.*conj(u2))+(v1.*conj(v2)));

return