function [k1, k2, uu] = calc_KE_fourier(X,Y,U,V)
% CALC_KE_FOURIER  Calculates the 2-dimensional KE spectral density without
%                  collapsing x and y dimensions to one dimension.
% Inputs: 
%       X: [n, 1] or [1, n] double, x-coordinates of velocity field
%       Y: [m, 1] or [1, m] double, y-coordinates of velocity field
%       U: [m, n] double, u-component of velocity field
%       V: [m, n] double, v-component of velocity field
% Outputs:
%       k1: wavenumber in x-direction
%       k2: wavenumber in y-direction
%       uu: [m, n] double, 2-dimensional KE spectral density of U,V


[k1, k2] = get_k_2dFourier(X, Y);
dx = abs(X(2)-X(1)); dy = abs(Y(2)-Y(1));

%_________________following paragraph replaced by get_k_2dFourier()________
% nyquist_k = 1/2 ./ [dx, dy];
% NX = length(X); NY = length(Y);
% dk = 1 ./ [floor(NX/2)*2.0*dx, floor(NY/2)*2.0*dy];
% %dk = 1 ./ [length(X)*dx, length(Y)*dy];
% % dk = 2*pi/(length(Y)*dy);
% 
% k1 = (-nyquist_k(1)) : dk(1) : (nyquist_k(1)-dk(1));
% k2 = (-nyquist_k(2)) : dk(2) : (nyquist_k(2)-dk(2));
% 
% if mod(length(X),2) == 1
%     k1 = [k1, nyquist_k(1)];
% end
% 
% if mod(length(Y),2) == 1
%     k2 = [k2, nyquist_k(2)];
% end


%k1 = [ 0 : dk(1) : (nyquist_k(1)-dk(1)), (-nyquist_k(1)):dk(1):(-dk(1))];
%k2 = [(-nyquist_k(2)) : dk(2) : (nyquist_k(2)-dk(2))];
%k2 = k1;

u = fftshift(fft2(U)).*dx; v = fftshift(fft2(V)).*dy;
uu = 0.5 .* (u.*conj(u) + v.*conj(v));


return