function [Ax, Ax_periodic] = ddx2(dx, A)
% DDX2  partially differentiates matrix A in x by mid-point method at a
%       constant dx.
% Inputs: 
%       dx: double, delta x
%       A: [m, n] double, matrix to be differentiated
% Outputs:
%       Ax: [m-2, n-2] double, partial derivative of A in x
%       Ax_periodic: [m, n] double, for periodic A, partial derivative of A 
%                    including left and right boundaries


Ax = (A(2:end-1, 3:end) - A(2:end-1, 1:end-2)) ./(2*dx);
Ax_periodic = [A(:,2)-A(:,end), A(:,3:end)-A(:,1:end-2), A(:,1)-A(:,end-1)] ./ (2*dx);

return