function [Ay, Ay_periodic] = ddy2(dy, A)
% DDY2  partially differentiates matrix A in y by mid-point method at a
%       constant dy.
% Inputs: 
%       dy: double, delta y
%       A: [m, n] double, matrix to be differentiated
% Outputs:
%       Ay: [m-2, n-2] double, partial derivative of A in y
%       Ay_periodic: [m, n] double, for periodic A, partial derivative of A 
%                    including top and bottom boundaries

Ay = (A(3:end, 2:end-1) - A(1:end-2, 2:end-1)) ./ (2*dy);
Ay_periodic = [A(2,:)-A(end,:); A(3:end,:)-A(1:end-2,:); A(1,:)-A(end-1,:)] ./ (2*dy);

return