clc; clear; close all

data_dir_d = '../figure_data/figure4/';

%% set parameters
td = '160503gd'; % 2016/05/13 
dt_sec = seconds(diff([datetime('14:46:00'), datetime('16:34:00')]));
satellites = 'TA';
im_px_size = 250.0; % m

% Tapering methods set to off
tp = ''; hn = '';

% Step sizes to be evaluated by coherence calculation with those in
% px2_list
px1_list = [2,4,8]';

% Coarser step sizes than in px1_list, to be interpolated to those finer 
% sizes for coherence calculation
px2_list = [4,8,16]'; 

standard_px = 4; PIV_fin_step = standard_px;

%% load u,v of all step sizes
allpx = [px1_list(:); px2_list(:)]; allpx = unique(allpx);

for px = allpx'
    px_fn_ext = '';

    % file extension if not standard_px
    if px ~= standard_px;        px_fn_ext = ['-', num2str(px),'pix']; end

    ss = ['ss', num2str(px)]; % step size string, e.g. 'ss2'

    % load U,V,X,Y into struct
    [UV.(ss).U, UV.(ss).V, UV.(ss).X, UV.(ss).Y] ...
        = load_ice_uvxy([data_dir_d, td, '_', satellites, px_fn_ext, '.mat'], ...
                        im_px_size, dt_sec, hn, tp); 

    UV.(ss).X = UV.(ss).X(1:size(UV.(ss).U, 2));
    UV.(ss).Y = UV.(ss).Y(1:size(UV.(ss).U, 1));
end

%% interp2. and calculate correlations
% For each step size in px1_list
for i_px1 = 1:length(px1_list)
    px1 = px1_list(i_px1);
    ss1 = ['ss', num2str(px1)]; % step size string, e.g. 'ss2'
    
    px2 = px2_list(i_px1); % choose the corresponding step size from px2_list

    ss2 = ['ss', num2str(px2)];
    
    % The following 4 outputs are contained in the struct Co.(ss1).(ss2):
    % [horiz. wavenumber, correlation between UV.(ss1) and UV.(ss2), ...
    %   autocorrelation of UV.(ss1), autocorrelation of UV.(ss2)]
    [Co.(ss1).(ss2).r, Co.(ss1).(ss2).corr, ...
        Co.(ss1).(ss2).acorr1, Co.(ss1).(ss2).acorr2]...
        = corr_interp_orig(px2/px1, UV.(ss1), UV.(ss2));
end

%% calculate and plot coherence from correlation
px2_legend_list = [char('Step size '.*ones(size(px2_list))), num2str(px1_list), ...
    char(' to '.*ones(size(px2_list))), num2str(px2_list)];

figure

min_k_plot = 1; max_k_plot = 1e-15;

% For each step size in px1_list
for i_px1 = 1:length(px1_list)
    px1 = px1_list(i_px1);
    ss1 = ['ss', num2str(px1)]; % step size string, e.g. 'ss2'
    
    % For each step size in px2_list, to be compared with px1
    for px2 = px2_list(i_px1, :)
        ss2 = ['ss', num2str(px2)]; % step size string, e.g. 'ss4'
        min_k_plot = min(min_k_plot, min(Co.(ss1).(ss2).r)); % min wavenumber to plot
        max_k_plot = max(max_k_plot, max(Co.(ss1).(ss2).r)); % max wavenumber to plot

        % Calculate coherence from correlation and autocorr.
        coherence = Co.(ss1).(ss2).corr.*conj(Co.(ss1).(ss2).corr) ./ Co.(ss1).(ss2).acorr1 ...
                                           ./ Co.(ss1).(ss2).acorr2;

        % plot coherence as a function of wavenumber
        plot(Co.(ss1).(ss2).r, coherence, 'linewidth', 1.5);
        hold on
    end

    set(gca, 'xscale', 'log')
    xlabel('horizontal wavenumber [cpm]')
    ylabel('Coherence', 'interpreter', 'latex')
    xlim([min_k_plot, max_k_plot])
end

legend(px2_legend_list, 'location', 'sw')


