clear; clc; close all;

data_dir_d = '../figure_data/figure5/';
scr_dir = data_dir_d; % screenshot directory (contains mask(s).mat)

%% [ARCHIVE] load special case: 160503g (with cut Suomi)
Im_fn_T = ['160503gc', '_1446-T']; % filename: Terra in 250m resolution

Im_T = imread([scr_dir, Im_fn_T, '.png']);

y_Im_T = 1:size(Im_T, 1); x_Im_T = 1:size(Im_T, 2);

%% load u,v with mask
ice_grid_meter = 250.0; 
dt_sec = seconds(diff([datetime('14:46:00'), datetime('16:34:00')]));
satellites = 'TA';
im_px_size = 250.0; % m

% Tapering methods set to off
tp = ''; hn = '';

uv_fn = '160503gc_masked';
[U,V,X,Y] = load_ice_uvxy([data_dir_d, uv_fn], ...
                          250.0, dt_sec, '', '');
dx = X(1,2)-X(1,1);

%% Set Suomi cut location, box (region) used in figure 8, and box to zoom in to in subplot(1,2,2)

% set Suomi cut location
theta_uv = 17.25; % deg

x0_cut = 25500; % meter, where X(1,1) = Y(1,1) = 1250m
x_cut = X(1,1)+ice_grid_meter.* x_Im_T; k = tan(pi/2-theta_uv/180*pi);
y_cut = Y(1,1)+ice_grid_meter.* y_Im_T(end)-(k.*x_cut-k*x0_cut);

% trim y_cut, x_cut to be inside the image domain
x_cut = x_cut(y_cut>=125); y_cut = y_cut(y_cut>=125);

y_box_left = Y(1,1)+ice_grid_meter.* y_Im_T(end)-(k.*x_cut-k*(x0_cut+2*ice_grid_meter));
%y_box_left = y_box_left(y_box_left>=125);
box_y_rot = 229000; box_x_rot = 91000; % meter
box_y = box_y_rot*cos(theta_uv/180*pi); box_x = box_x_rot*cos(theta_uv/180*pi);
[~, i_box_y0] = min(abs(y_box_left-(box_y+y_box_left(end)))); 

box_x0 = x_cut(219); box_y0 = y_box_left(219);
box_x1 = x_cut(219)+box_y_rot*sin(theta_uv/180*pi); box_y1 = box_y0-box_y;


%% plot
% (i)   'autoscalefactor', 2, 'linewidth', 0.8, 'maxheadsize', 0.4
% (ii)  transparent 
% (iii) rotate

nQv = 5; 

nx_im = length(x_Im_T); ny_im = length(y_Im_T); nx_uv = length(X); ny_uv = length(Y);
j_crop_uv = 90+(1:40); 
i_crop_uv = 40+(1:round(length(j_crop_uv)*ny_uv/nx_uv));
i_crop_uv_flip = (ny_uv-i_crop_uv(end)):(ny_uv-i_crop_uv(1));

i_crop_im = (i_crop_uv(1)*4):(i_crop_uv(end)*4); 
i_crop_im_flip = (i_crop_uv_flip(1)*4):(i_crop_uv_flip(end)*4);
j_crop_im = (j_crop_uv(1)*4):(j_crop_uv(end)*4);


figure

% Entire region with mask
subplot(1,2,1)
imagesc((X(1,1)/2+ice_grid_meter.* x_Im_T)./1000, ...
        (Y(1,1)/2+ice_grid_meter.* y_Im_T)./1000, flipud(mean(Im_T,3)), ...
        'AlphaData', 0.7)
colormap('gray'); clim([0 255]); daspect([1 1 1])

hold on

h_SuomiCut = plot(x_cut./1000, y_cut./1000, '--', 'linewidth', 1.5, 'color', [1 1 1]);
h_selectBox = plot([box_x0, box_x1, box_x1+box_x, box_x0+box_x, box_x0]./1000, ...
    [box_y0, box_y1, box_y1+1/k*box_x, box_y0+1/k*box_x, box_y0]./1000, ...
    'linewidth', 2, 'color', [1 1 1]);
h_zoomBox = plot([X(j_crop_uv(1)), X(j_crop_uv(1)), X(j_crop_uv(end)),X(j_crop_uv(end)),X(j_crop_uv(1))]./1000, ...
    [Y(i_crop_uv(1)), Y(i_crop_uv(end)), Y(i_crop_uv(end)), Y(i_crop_uv(1)), Y(i_crop_uv(1))]./1000, ...
    'linewidth', 1.5, 'color', 'g');

quiver(X(1:nQv:end, 1:nQv:end)./1000, Y(1:nQv:end, 1:nQv:end)./1000, ...
    flipud(U(1:nQv:end, 1:nQv:end)), flipud(-V(1:nQv:end, 1:nQv:end)), 'r', ...
    'autoscalefactor', 2, 'linewidth', 1, 'maxheadsize', 0.4)

axis xy
daspect([1 1 1])
xlabel('$x$ [km]', 'Interpreter', 'latex'); ylabel('$y$ [km]', 'Interpreter', 'latex')

% Zoomed-in on green box of subplot(1,2,1), plot every vector
subplot(1,2,2)
imagesc((X(1,1)/2+ice_grid_meter.* x_Im_T(j_crop_im))./1000, ...
        (Y(1,1)/2+ice_grid_meter.* y_Im_T(i_crop_im))./1000, flipud(mean(Im_T(i_crop_im_flip,j_crop_im,:),3)), ...
        'AlphaData', 0.7)
colormap('gray'); clim([0 255]); daspect([1 1 1])
set(gca, 'YAxisLocation', 'right')
axis xy

hold on

quiver(X(j_crop_uv)./1000, Y(i_crop_uv)./1000, ...
    flipud(U(i_crop_uv_flip,j_crop_uv)), flipud(-V(i_crop_uv_flip,j_crop_uv)), 'r', ...
    'autoscalefactor', 2, 'linewidth', 1, 'maxheadsize', 0.4)

daspect([1 1 1])
xlabel('$x$ [km]', 'Interpreter', 'latex'); ylabel('$y$ [km]', 'Interpreter', 'latex')
