clear; clc; close all

data_dir_d = '../figure_data/figure7/';


%% plot KE spectra of means
td = '160503g';
bands = [1,3,4]; % satellite true-color images bands/channels

% load U,V (prev. saved with archived code in the last section of this script)
for i_band = bands
    fn_band = ['-B', num2str(i_band)];

    load([data_dir_d, td, 'weighted', fn_band, '_rot'], 'Xd', 'Yd', 'Ud', 'Vd')
    load([data_dir_d, td, '_TA', fn_band, '_rot'], 'Ud13', 'Vd13')

    % KE spectrum: weighted (T-S, S-A)
    [k1,k2,uu] = calc_KE_fourier(Xd,Yd,Ud,Vd);
    [r_k_d, mean_uu_polar] = calc_polar_spectrum(k1,k2,uu);
    
    % KE spectrum: direct, Terra-Aqua
    [~,~,u3u3] = calc_KE_fourier(Xd,Yd,Ud13,Vd13);
    [~, mean_u3u3_polar] = calc_polar_spectrum(k1,k2,u3u3);

    int_d = length(Xd)*length(Yd);

    figure(1)
    loglog(r_k_d, mean_uu_polar./int_d, 'r', 'linewidth', 1.5)
    hold on
    loglog(r_k_d, mean_u3u3_polar./int_d, 'k')
    xlim([2./min(Xd(end),Yd(end)),r_k_d(end)])
    xlabel('horizontal wavenumber [cpm]', 'interpreter', 'latex')
    ylabel('KE density [m$^3$ s$^{-2}$]', 'interpreter', 'latex')

    clear Ud Vd % same varnames used in next iteration (band)
end

% dim 3 of mean_Ud/Vd has size 4: satellite pairs T-S, S-A, T-A, weighted
load([data_dir_d, td, 'bandAvg_rot'], 'mean_Ud', 'mean_Vd')

% KE spectra
% Unweighted ("direct") mean of three bands (T-A bands 1,3,4)
[~,~,uu_mean_uw] = calc_KE_fourier(Xd,Yd, ...
                                   mean_Ud(:,:,3), mean_Vd(:,:,3));
[~, mean_uu_polar_mean_uw] = calc_polar_spectrum(k1,k2,uu_mean_uw);

% Weighted mean
[k1,k2,uu_mean] = calc_KE_fourier(Xd,Yd,mean_Ud(:,:,4),mean_Vd(:,:,4));
[~, mean_uu_polar_mean] = calc_polar_spectrum(k1,k2,uu_mean);

% Mean of direct & weighted
[k1,k2,uu_mean_dw] = ...
    calc_KE_fourier(Xd,Yd, mean(mean_Ud(:,:,3:4),3),mean(mean_Vd(:,:,3:4),3));
[~, mean_uu_polar_mean_dw] = calc_polar_spectrum(k1,k2,uu_mean_dw);

int_d = length(Xd)*length(Yd); % normalization factor

figure(1)
hold on
loglog(r_k_d, mean_uu_polar_mean./int_d, 'b', 'linewidth', 1.5)
hold on
loglog(r_k_d, mean_uu_polar_mean_uw./int_d, 'b--', 'linewidth', 1.5)
loglog(r_k_d, mean_uu_polar_mean_dw./int_d, 'm', 'linewidth', 1.5)
%end

legend('weighted-B1','direct-B1', 'weighted-B3','direct-B3', 'weighted-B4','direct-B4', ...
    'weighted-all bands', 'direct-all bands', 'mean of weighted & direct - all bands')

%% [ARCHIVE] crop, rotate U,V in selected region, and save
data_dir_out = data_dir_d;

bands = [1,3,4]; % satellite true-color images bands/channels
ice_grid_meter = 250.0; % image resolution in METERS
theta_uv = 17; % angle of U,V rotation in DEGREES

td = '160503g';

% Difference between satellite passing times in SECONDS
dt_sec_12 = seconds(diff(datetime(['14:46:00'; '15:22:00']))); % Terra/Suomi
dt_sec_23 = seconds(diff(datetime(['15:22:00'; '16:34:00']))); % Suomi/Aqua

% For each band in the RGB channels of true-color images
for i_band = bands
    fn_band = ['-B', num2str(i_band)];

    % Snapshot pair 1,2
    [Ud12, Vd12, Xd, Yd] = ...
        load_ice_uvxy([data_dir_d, '160503g_TS', fn_band, '_6pix', '.mat'], ...
                      ice_grid_meter, dt_sec_12, '', '');

    % Snapshot pair 2,3
    [Ud23, Vd23, ~, ~] = ...
        load_ice_uvxy([data_dir_d, '160503g_SA', fn_band, '_6pix', '.mat'], ...
                      ice_grid_meter, dt_sec_23, '', '');

    % Snapshot pair 1,3
    [Ud13, Vd13, ~, ~] = ...
        load_ice_uvxy([data_dir_d, '160503g_TA', fn_band, '_6pix', '.mat'], ...
                      ice_grid_meter, dt_sec_12+dt_sec_23, '', '');

    dx = abs(Xd(2)-Xd(1)); dy = abs(Yd(2)-Yd(1));

    % Rotate U,V
    [Ud12_r, Vd12_r] = rotate_2D_UV(Ud12, Vd12, theta_uv);
    [Ud23_r, Vd23_r] = rotate_2D_UV(Ud23, Vd23, theta_uv);
    [Ud13_r, Vd13_r] = rotate_2D_UV(Ud13, Vd13, theta_uv);

    % Crop rotated u,v
    j_rot_left = 79; % ceil(118*4/6)
    j_rot_right = 120; % floor(181*4/6)
    i_rot_top = 34; % ceil(50*4/6)
    i_rot_bottom = 197; % floor(296*4/6)

    Ud12_r = Ud12_r(i_rot_top:i_rot_bottom,j_rot_left:j_rot_right);
    Vd12_r = Vd12_r(i_rot_top:i_rot_bottom,j_rot_left:j_rot_right);
    Ud23_r = Ud23_r(i_rot_top:i_rot_bottom,j_rot_left:j_rot_right);
    Vd23_r = Vd23_r(i_rot_top:i_rot_bottom,j_rot_left:j_rot_right);
    Ud13_r = Ud13_r(i_rot_top:i_rot_bottom,j_rot_left:j_rot_right);
    Vd13_r = Vd13_r(i_rot_top:i_rot_bottom,j_rot_left:j_rot_right);

    Xdr = (0:(j_rot_right-j_rot_left)).*dx;
    Ydr = (0:(i_rot_bottom-i_rot_top)).*dy;

    Ud_r = Ud12_r.*(dt_sec_12/(dt_sec_12+dt_sec_23)) ...
           + Ud23_r.*(dt_sec_23/(dt_sec_12+dt_sec_23));
    Vd_r = Vd12_r.*(dt_sec_12/(dt_sec_12+dt_sec_23)) ...
           + Vd23_r.*(dt_sec_23/(dt_sec_12+dt_sec_23));

    % Change rotated variable names to normal
    Ud = Ud_r; Vd = Vd_r;
    Ud12 = Ud12_r; Vd12 = Vd12_r;
    Ud23 = Ud23_r; Vd23 = Vd23_r;
    Ud13 = Ud13_r; Vd13 = Vd13_r;
    Xd = Xdr; Yd = Ydr;
    clear Ud_r Vd_r Ud12_r Vd12_r Ud23_r Vd23_r Ud13_r Vd13_r Xdr Ydr

    save([data_dir_out, td, '_TS', fn_band, '_rot'], 'Xd', 'Yd', 'Ud12', 'Vd12');
    save([data_dir_out, td, '_SA', fn_band, '_rot'], 'Xd', 'Yd', 'Ud23', 'Vd23');
    save([data_dir_out, td, '_TA', fn_band, '_rot'], 'Xd', 'Yd', 'Ud13', 'Vd13');
    save([data_dir_out, td, 'weighted', fn_band, '_rot'], 'Xd', 'Yd', 'Ud', 'Vd');

    % Sum by bands in for loop and save in mean_Ud, mean_Vd
    if i_band == 1 % 1st iteration
        mean_Ud = zeros(size(Ud12,1), size(Ud12,2), 4);
        mean_Vd = zeros(size(Vd12,1), size(Vd12,2), 4);

        % dim 3: satellite pairs T-S, S-A, T-A, weighted
        mean_Ud(:,:,1) = Ud12; mean_Vd(:,:,1) = Vd12; 
        mean_Ud(:,:,2) = Ud23; mean_Vd(:,:,2) = Vd23;
        mean_Ud(:,:,3) = Ud13; mean_Vd(:,:,3) = Vd13;
        mean_Ud(:,:,4) = Ud; mean_Vd(:,:,4) = Vd;
    else % not 1st iteration
        mean_Ud(:,:,1) = mean_Ud(:,:,1)+Ud12; mean_Vd(:,:,1) = mean_Vd(:,:,1)+Vd12; 
        mean_Ud(:,:,2) = mean_Ud(:,:,2)+Ud23; mean_Vd(:,:,2) = mean_Vd(:,:,2)+Vd23;
        mean_Ud(:,:,3) = mean_Ud(:,:,3)+Ud13; mean_Vd(:,:,3) = mean_Vd(:,:,3)+Vd13;
        mean_Ud(:,:,4) = mean_Ud(:,:,4)+Ud; mean_Vd(:,:,4) = mean_Vd(:,:,4)+Vd;
    end

end

% Compute mean from the sum saved over for loop iterations
mean_Ud = mean_Ud./length(bands); mean_Vd = mean_Vd./length(bands);

save([data_dir_out, td, 'bandAvg_rot'], 'Xd', 'Yd', 'mean_Ud', 'mean_Vd');
