clc; clear; close all

data_dir_d = '../figure_data/figure8/';

%% set parameters
td = '160503gd'; % 2016/05/13 
dt_sec = seconds(diff([datetime('14:46:00'), datetime('16:34:00')]));
satellites = 'TA';
im_px_size = 250.0; % m

tp = 'taper'; % tanh tapering boundaries
hn = ''; % not using Hanning window

fcor = 2*(2*pi/3600/24)*sin(58/180*pi); % f at 58deg N

%% load de-noised data
% method1a = band averaging at dx250m,
% method1b = band averaging at dx500m,
% method2  = weighted multiple satellites
% method3  = combine 1b and 2 (avg. of the two)

method = '3';

switch method
    case '1a'
        dx = 'x250';
        UV = load([data_dir_d, td, '_bandAvg_TA.mat']); UV = UV.UV_bandAvg.(dx);
        Ud = UV.U; Vd = UV.V; Xd = UV.X; Yd = UV.Y;
    case '1b'
        dx = 'x500';
        UV = load([data_dir_d, td, '_bandAvg_TA.mat']); UV = UV.UV_bandAvg.(dx);
        Ud = UV.U; Vd = UV.V; Xd = UV.X; Yd = UV.Y;
    case '2'
        UV = load([data_dir_d, td, '_weightedSat_500.mat']); UV = UV.UV_weighted;
        Ud = UV.U; Vd = UV.V; Xd = UV.X; Yd = UV.Y;
    case '3'
        UV1 = load([data_dir_d, td, '_bandAvg_TA.mat']); UV1 = UV1.UV_bandAvg.x500;
        Ud1 = UV1.U; Vd1 = UV1.V; Xd1 = UV1.X; Yd1 = UV1.Y;
        UV2 = load([data_dir_d, td, '_weightedSat_500.mat']); UV2 = UV2.UV_weighted;
        Ud2 = UV2.U; Vd2 = UV2.V; Xd2 = UV2.X; Yd2 = UV2.Y;
        Xd = Xd1; Yd = Yd1;
        Ud = (Ud1+Ud2)./2; Vd = (Vd1+Vd2)./2;
    otherwise; error(['De-noising method ', method, ' does not exist.'])
end

[Ud,Vd] = taper_2D_UV(Xd,Yd,Ud,Vd, hn,tp);


%% Decompose U,V
[k1, k2, ~] = calc_KE_fourier(Xd,Yd,Ud,Vd); [K1, K2] = meshgrid(k1,k2);
[Up,Vp,Us,Vs] = decomp_helmholtz(Ud,Vd,K1,K2);

%% Differentiation
Upx = ddx2_spec(K1,Up); Upy = ddy2_spec(K2,Up);
Vpx = ddx2_spec(K1,Vp); Vpy = ddy2_spec(K2,Vp);
Usx = ddx2_spec(K1,Us); Usy = ddy2_spec(K2,Us);
Vsx = ddx2_spec(K1,Vs); Vsy = ddy2_spec(K2,Vs);

%% plot: div(Up)=\=0, vort(Us)=\=0
figure
nQv = 2; autoScaleFactor = 2; quiverLineWidth = 1.5;

subplot(1, 2, 1)
imagesc(Xd./1000, Yd./1000, flipud(Upx+Vpy)./fcor)
colormap(cmocean('curl')); colorbar; caxis([-.75, .75])
daspect([1 1 1]); axis xy

hold on
quiver(Xd(1:nQv:end)./1000, Yd(1:nQv:end)./1000, ...
    flipud(Up(1:nQv:end,1:nQv:end)), flipud(-Vp(1:nQv:end,1:nQv:end)), ...
    'k', 'autoscalefactor', autoScaleFactor, 'linewidth', quiverLineWidth)
title('$\nabla \cdot \mathbf{u}_p / f$', 'interpreter', 'latex') % div Up
xlabel('$x$ [km]','interpreter','latex'); ylabel('$y$ [km]','interpreter', 'latex');

subplot(1, 2, 2)
imagesc(Xd./1000, Yd./1000, flipud(-(Vsx-Usy))./fcor)
colormap(cmocean('curl')); colorbar; caxis([-.75, .75])
daspect([1 1 1]); axis xy

hold on
quiver(Xd(1:nQv:end)./1000, Yd(1:nQv:end)./1000, ...
    flipud(Us(1:nQv:end,1:nQv:end)), flipud(-Vs(1:nQv:end,1:nQv:end)), ...
    'k', 'autoscalefactor', autoScaleFactor, 'linewidth', quiverLineWidth)
title('$\nabla \times \mathbf{u}_s / f$', 'interpreter', 'latex') % vort Us
xlabel('$x$ [km]','interpreter', 'latex'); ylabel('$y$ [km]','interpreter', 'latex');




