function [k1, k2] = get_k_2dFourier(X, Y)
% GET_K_2DFOURIER  Determines the x- and y- wavenumbers when applying 2D
%                  FT on any 2-D matrix with coordinates X and Y.
% Inputs: 
%       X: [n, 1] or [1, n] double, x-coordinates
%       Y: [m, 1] or [1, m] double, y-coordinates
% Outputs:
%       k1: [1, n] double, wavenumber in x-direction
%       k2: [1, m] double, wavenumber in y-direction

dx = abs(X(2)-X(1)); dy = abs(Y(2)-Y(1));
nyquist_k = 1/2 ./ [dx, dy];
NX = length(X); NY = length(Y);

%dk = 1 ./ [floor(NX/2)*2.0*dx, floor(NY/2)*2.0*dy];
dk = 1/2 ./ [floor(NX/2)*dx, floor(NY/2)*dy]; % eqv. to above
%dk = 1 ./ [length(X)*dx, length(Y)*dy];
% dk = 2*pi/(length(Y)*dy);

k1 = (-nyquist_k(1)) : dk(1) : (nyquist_k(1)-dk(1));
k2 = (-nyquist_k(2)) : dk(2) : (nyquist_k(2)-dk(2));

% Append nyquist wavenumber on the positive end if m or n is odd
if mod(NX,2) == 1;   k1 = [k1, nyquist_k(1)];    end
if mod(NY,2) == 1;   k2 = [k2, nyquist_k(2)];    end

return