function [Ur, Vr] = rotate_2D_UV(U, V, theta)
% ROTATE_2D_UV  Rotates a 2D velocity field (U,V) counter-clockwise by
%               an angle of theta.
% Inputs: 
%       U: [m, n] double, u-component of the velocity field
%       V: [m, n] double, v-component of the velocity field
%       theta: double, angle of rotation in DEGREES
% Outputs:
%       Ur: u-component of the rotated velocity field
%       Vr: v-component of the rotated velocity field


theta_rad = theta/180*pi;

Ur = U.*cos(theta_rad) - (V).*sin(theta_rad);
Vr = (U.*sin(theta_rad) + (V).*cos(theta_rad));

theta = -theta;

Ur = imrotate(Ur, theta); Vr = imrotate(Vr, theta);

return