function [Ut, Vt] = taper_2D_UV(X,Y,U,V, hn, tp)
% TAPER_2D_UV  Tapers U,V with the Hanning Window and/or tanh method.
% Inputs: 
%       X: [n, 1] or [1, n] double, x-coordinates of velocity field
%       Y: [m, 1] or [1, m] double, y-coordinates of velocity field
%       U: [m, n] double, u-component of velocity field
%       V: [m, n] double, v-component of velocity field
%       hn: char array, option to apply hanning window if non-empty char
%       tp: char array, option to apply sine tapering if non-empty char
% Outputs:
%       Ut: tapered u-component of velocity field
%       Vp: tapered v-component of velocity field

Ut = U; Vt = V;

% Hanning Window
if sum(hn)
    Ut = U .* (hann(length(X))*hann(length(Y))')';
    Vt = V .* (hann(length(X))*hann(length(Y))')';
end

% tanh tapering
if sum(tp)
    [Ut, Vt] = apply_tanh_tapering(X, Y, U, V, 10);
end

return